API
===


Probability Distributions
-------------------------

.. toctree::

    gradoptics.distributions.base_distribution
    gradoptics.distributions.gaussian_distribution
    gradoptics.distributions.atom_cloud


Optical Elements
----------------

.. currentmodule:: gradoptics.optics

.. toctree::

    gradoptics.optics.base_optics
    gradoptics.optics.camera
    gradoptics.optics.lens
    gradoptics.optics.mirror
    gradoptics.optics.sensor
    gradoptics.optics.ray
    gradoptics.optics.window
    gradoptics.optics.psf
    gradoptics.optics.bounding_sphere
    gradoptics.optics.vector


Transforms
----------

.. toctree::

    gradoptics.transforms.base_transform
    gradoptics.transforms.look_at_transform
    gradoptics.transforms.simple_transform


Ray Tracing
-----------

.. toctree::

    gradoptics.ray_tracing.ray_tracing
    gradoptics.ray_tracing.scene


Light Sources
-------------

.. toctree::

    gradoptics.light_sources.base_light_source
    gradoptics.light_sources.lightSource_from_distribution


Inference
---------

.. toctree::

    gradoptics.inference.rejection_sampling
